def create(values = None):
  record = {
    "ampTier": None,
    "acmgTier": None,
    "alternativeTierSystems": None,
    "calledBy": None,
    "sequenceType": None,
    "coordinateSystem": None,
    "genomeBuild": None,
    "orientation": None,
    "strand": None,
    "chrom": None,
    "pos": None,
    "ref": None,
    "alt": None,
    "filter": None,
    "id": None,
    "qual": None,
    "infoRaw": None,
    "formatRaw": None,
    "sampleRaw": None,
    "genotype": None,
    "readDepth": None,
    "refAlleleDepth": None,
    "altAlleleDepth": None,
    "altAlleleFraction": None,
    "refAlleleDepthFwdStrand": None,
    "refAlleleDepthRevStrand": None,
    "altAlleleDepthFwdStrand": None,
    "altAlleleDepthRevStrand": None,
    "altAlleleFractionFwdStrand": None,
    "altAlleleFractionRevStrand": None,
    "cigar": None,
    "gene": None,
    "transcript": None,
    "protein": None,
    "variantClassification": None,
    "variantType": None,
    "hgvsG": None,
    "hgvsC": None,
    "hgvsP": None,
    "hgvsPShort": None,
    "hotspot": None,
    "zygosity": None,
    "interpretation": None,
    "therapyRecommendation": None,
  }
  if values!=None:
    record.update(values)
  return record
